"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const moduleAlias = require("module-alias");
moduleAlias.addAliases({
    '@modules': `${__dirname}/modules`,
    '@src': `${__dirname}`,
});
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const app_module_1 = require("./app.module");
const httpContext = require("express-http-context");
const common_2 = require("@moonlightjs/common");
const prisma_service_1 = require("./infra/prisma/prisma.service");
const setup_swagger_1 = require("./setup-swagger");
const PORT = process.env.PORT || 1999;
async function bootstrap() {
    const app = await core_1.NestFactory.create(app_module_1.AppModule);
    const prismaService = app.get(prisma_service_1.PrismaService);
    await prismaService.enableShutdownHooks(app);
    app.useGlobalPipes(new common_1.ValidationPipe());
    app.useGlobalPipes(new common_2.FilterPipe());
    app.enableCors();
    app.use(httpContext.middleware);
    app.use('/api', common_2.GlobalApiLoggerMiddleware);
    app.useGlobalInterceptors(new common_2.TransformInterceptor());
    app.useGlobalInterceptors(new common_2.ResponseInterceptor());
    app.useGlobalFilters(new common_2.GlobalExceptionFilter());
    app.setGlobalPrefix('api');
    app.enableVersioning({
        type: common_1.VersioningType.URI,
    });
    if ((0, common_2.isDevelopment)()) {
        (0, setup_swagger_1.setupSwagger)(app);
    }
    await app.listen(PORT, () => console.log(`🚀 Server ready at http://localhost:${PORT}`));
}
bootstrap().then();
//# sourceMappingURL=main.js.map