"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminAuthenticationService = void 0;
const admin_jwt_sign_option_1 = require("./admin-jwt-sign-option");
const common_1 = require("@nestjs/common");
const config_1 = require("@nestjs/config");
const jwt_1 = require("@nestjs/jwt");
const constants_1 = require("../../constants");
const prisma_service_1 = require("../../infra/prisma/prisma.service");
const common_2 = require("@moonlightjs/common");
const bcrypt = require("bcrypt");
const dto_1 = require("../admin-user/dto");
let AdminAuthenticationService = class AdminAuthenticationService {
    constructor(prisma, jwtService, configService) {
        this.prisma = prisma;
        this.jwtService = jwtService;
        this.configService = configService;
        this._accessTokenOption = (0, admin_jwt_sign_option_1.adminAccessTokenOption)(configService);
        this._refreshTokenOption = (0, admin_jwt_sign_option_1.adminRefreshTokenOption)(configService);
    }
    async validateUser(input) {
        const user = await this.prisma.adminUser.findFirst({
            where: {
                username: input.username,
            },
            include: {
                roles: {
                    include: {
                        permissions: true,
                    },
                },
            },
        });
        if (user) {
            if (!user.password) {
                throw new common_2.HttpErrorException(constants_1.AdminUserErrorCodes.PasswordInvalid);
            }
            const isPasswordMatching = await bcrypt.compare(input.password, user.password);
            if (isPasswordMatching) {
                return user;
            }
            throw new common_2.HttpErrorException(constants_1.AdminUserErrorCodes.PasswordInvalid);
        }
        return null;
    }
    async login(user) {
        this.prisma.adminUser
            .update({
            where: {
                id: user.id,
            },
            data: {
                lastLogin: new Date(),
            },
        })
            .then();
        const roles = user.roles ? user.roles.map((role) => role.code) : [];
        const permissions = [];
        user.roles.forEach((role) => {
            role.permissions.forEach((permission) => {
                permissions.push(permission.action);
            });
        });
        const payload = {
            username: user.username,
            sub: user.id,
            roles,
            permissions,
        };
        return {
            accessToken: this.jwtService.sign(payload),
            refreshToken: this.jwtService.sign(payload, this._refreshTokenOption),
            user: (0, common_2.toDto)(dto_1.AdminUserProfileDto, user),
        };
    }
    async refreshToken(payloadRefreshToken) {
        {
            const user = await this.prisma.adminUser.findFirst({
                where: {
                    id: payloadRefreshToken.sub,
                },
                include: {
                    roles: {
                        include: {
                            permissions: true,
                        },
                    },
                },
            });
            if (!user) {
                throw new common_2.HttpErrorException(constants_1.AdminUserErrorCodes.UserNotExists);
            }
            const roles = user.roles ? user.roles.map((role) => role.code) : [];
            const permissions = [];
            user.roles.forEach((role) => {
                role.permissions.forEach((permission) => {
                    permissions.push(permission.action);
                });
            });
            const payload = {
                username: payloadRefreshToken.username,
                sub: payloadRefreshToken.sub,
                roles,
                permissions,
            };
            return {
                accessToken: this.jwtService.sign(payload),
                refreshToken: this.jwtService.sign(payload, this._refreshTokenOption),
            };
        }
    }
};
AdminAuthenticationService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService,
        jwt_1.JwtService,
        config_1.ConfigService])
], AdminAuthenticationService);
exports.AdminAuthenticationService = AdminAuthenticationService;
//# sourceMappingURL=admin-authentication.service.js.map